@@ -17,20 +17,25 @@ import os
 import shutil
 import subprocess
 import tempfile
+from contextlib import contextmanager
+from locale import normalize
 from pathlib import Path
 from typing import Any, Dict, Generator, Iterator, List, Optional, Tuple
 
 import cv2
 import numpy as np
+from numpy.f2py.symbolic import Op
 from PIL import Image
 from spacy.lang import en
+
 from .frame_metadata_extractor import FrameMetadataExtractor
 from .masking import MaskApplication
 from .ocr_frame import FrameOCR
-from .ocr_minicpm import (
-    _can_load_model,
-    create_minicpm_ocr,
-)
+
+# from .ocr_minicpm import (
+#     _can_load_model,
+#     create_minicpm_ocr,
+# )
 from .ollama_llm_meta_extraction_optimized import (
     EnrichedMetadataExtractor,
     FrameSamplingOptimizer,
@@ -40,6 +45,7 @@ from .roi_processor import ROIProcessor
 from .sensitive_meta_interface import SensitiveMeta
 from .spacy_extractor import PatientDataExtractor
 from .utils.ollama import ensure_ollama
+from .utils.roi_normalization import normalize_roi_keys
 from .video_encoder import VideoEncoder
 
 logger = logging.getLogger(__name__)
@@ -61,9 +67,9 @@ class FrameCleaner:
 
     def __init__(
         self,
-        use_minicpm: bool = True,
+        use_minicpm: Optional[bool] = False,
         minicpm_config: Optional[Dict[str, Any]] = None,
-        use_llm: bool = False,
+        use_llm: Optional[bool] = False,
     ):
         # Initialize specialized frame processing components
         self.frame_ocr = FrameOCR()
@@ -79,9 +85,9 @@ class FrameCleaner:
         self.use_llm = bool(use_llm)
 
         # Initialize MiniCPM-o 2.6 if enabled
-        self.use_minicpm = use_minicpm
-        self.minicpm_ocr = create_minicpm_ocr() if use_minicpm else None
-        self._log_hf_cache_info()
+        # self.use_minicpm = use_minicpm
+        # self.minicpm_ocr = create_minicpm_ocr() if use_minicpm else None
+        # self._log_hf_cache_info()
 
         # Initialize the optimized ollama processing pipeline (guarded)
         self.ollama_proc = None
@@ -133,30 +139,32 @@ class FrameCleaner:
         logger.info(f"Hardware acceleration: NVENC {'available' if self.nvenc_available else 'not available'}")
         logger.info(f"Using encoder: {self.preferred_encoder}")
 
-        if self.use_minicpm:
-            try:
-                minicpm_config = minicpm_config or {}
-                if _can_load_model():
-                    self.minicpm_ocr = create_minicpm_ocr(**minicpm_config)
-                else:
-                    logger.warning("Insufficient storage to load MiniCPM-o 2.6 model. Falling back to traditional OCR.")
-                    self.use_minicpm = False
-                    self.minicpm_ocr = None
+        # if self.use_minicpm:
+        #     logger.warning("MiniCPM currently not functional; falling back to TesserOCR.")
+        #     self.use_minicpm = False
 
-                logger.info("MiniCPM-o 2.6 initialized successfully")
-            except Exception as e:
-                logger.warning(f"Failed to initialize MiniCPM-o 2.6: {e}. Falling back to traditional OCR.")
-                self.use_minicpm = False
-                self.minicpm_ocr = None
+        # try:
+        #     minicpm_config = minicpm_config or {}
+        #     if _can_load_model():
+        #         self.minicpm_ocr = create_minicpm_ocr(**minicpm_config)
+        #     else:
+        #         logger.warning("Insufficient storage to load MiniCPM-o 2.6 model. Falling back to traditional OCR.")
+        #         self.use_minicpm = False
+        #         self.minicpm_ocr = None
+
+        #     logger.info("MiniCPM-o 2.6 initialized successfully")
+        # except Exception as e:
+        #     logger.warning(f"Failed to initialize MiniCPM-o 2.6: {e}. Falling back to traditional OCR.")
+        #     self.use_minicpm = False
+        #     self.minicpm_ocr = None
 
     def clean_video(
         self,
         video_path: Path,
         endoscope_image_roi: Optional[dict[str, int]],
-        endoscope_data_roi_nested: dict[str, dict[str, int | None] | None],
+        endoscope_data_roi_nested: Optional[dict[str, dict[str, int | None]] | list | None],
         output_path: Optional[Path] = None,
         technique: str = "mask_overlay",
-        extended: bool = False,
     ) -> tuple[Path, Dict[str, Any]]:
         """
         Handles the cleaning of a video by removing or masking frames with sensitive information.
@@ -167,15 +175,16 @@ class FrameCleaner:
             output_path: Optional path for the output cleaned video
             technique: 'remove_frames' or 'mask_overlay'
             extended: Whether to perform extended metadata extraction
-            
+
         Returns:
-            A tuple containing the output video path and a dictionary of sensitive metadata.        
-        
+            A tuple containing the output video path and a dictionary of sensitive metadata.
+
         Refactored version: single code path, fewer duplicated branches. Batch Metadata logic preserves previous output based on confidence.
         """
 
         output_video = output_path or video_path.with_stem(f"{video_path.stem}_anony")
         accumulated: dict[str, Any] = {
+            "file_path": str(object=video_path),
             "patient_first_name": None,
             "patient_last_name": None,
             "patient_dob": None,
@@ -212,14 +221,13 @@ class FrameCleaner:
                 endoscope_image_roi=endoscope_image_roi,
                 endoscope_data_roi_nested=endoscope_data_roi_nested,
                 frame_id=idx,
-                extended=extended,
-                collect_for_batch=extended,
+                collect_for_batch=True,
             )
             accumulated = self.frame_metadata_extractor.merge_metadata(accumulated, frame_meta)
             if is_sensitive:
                 sensitive_idx.append(idx)
         # Batch-Metadaten-Anreicherung nach Frame-Loop
-        if extended and self.frame_collection:
+        if self.frame_collection:
             batch_enriched = self._extract_enriched_metadata_batch()
             if batch_enriched:
                 accumulated = self.frame_metadata_extractor.merge_metadata(accumulated, batch_enriched)
@@ -253,9 +261,9 @@ class FrameCleaner:
         sensitive_meta = SensitiveMeta.from_dict(accumulated)
         return output_video, sensitive_meta.to_dict()
 
-    def _get_primary_ocr_engine(self) -> str:
-        """Return the name of the primary OCR engine being used."""
-        return "MiniCPM-o 2.6" if (self.use_minicpm and self.minicpm_ocr) else "FrameOCR + LLM"
+    # def _get_primary_ocr_engine(self) -> str:
+    #     """Return the name of the primary OCR engine being used."""
+    #     return "MiniCPM-o 2.6" if (self.use_minicpm and self.minicpm_ocr) else "FrameOCR + LLM"
 
     def _detect_video_format(self, video_path: Path) -> Dict[str, Any]:
         """
@@ -356,30 +364,19 @@ class FrameCleaner:
 
         return True
 
-    def _create_named_pipe(self, suffix: str = ".mp4") -> Path:
-        """
-        Create a named pipe (FIFO) for streaming video data.
-
-        Args:
-            suffix: File extension for the pipe name
-
-        Returns:
-            Path to created named pipe
-        """
-        # Create temporary directory for pipes
+    @contextmanager
+    def _named_pipe(self, suffix=".mp4"):
         temp_dir = Path(tempfile.mkdtemp(prefix="video_pipes_"))
         pipe_path = temp_dir / f"stream{suffix}"
-
+        os.mkfifo(pipe_path)
         try:
-            # Create named pipe
-            os.mkfifo(str(pipe_path))
-            logger.debug(f"Created named pipe: {pipe_path}")
-            return pipe_path
-
-        except OSError as e:
-            logger.error(f"Failed to create named pipe: {e}")
-            # Fallback to regular temp file
-            return temp_dir / f"fallback{suffix}"
+            yield pipe_path
+        finally:
+            try:
+                pipe_path.unlink()
+                temp_dir.rmdir()
+            except OSError:
+                pass
 
     def _stream_copy_with_pixel_conversion(
         self,
@@ -551,12 +548,10 @@ class FrameCleaner:
             logger.debug(f"Stream copy output: {result.stderr}")
             return output_video.exists() and output_video.stat().st_size > 0
 
-
         except Exception as e:
             logger.error(f"Stream copy error: {e}")
             return False
 
-
     def remove_frames_from_video_streaming(
         self,
         original_video: Path,
@@ -594,63 +589,62 @@ class FrameCleaner:
 
             if use_named_pipe and len(frames_to_remove) < (total_frames or 1000) * 0.1:
                 # Use named pipe for small frame removal operations
-                pipe_path = self._create_named_pipe(".mp4")
+                with self._named_pipe() as pipe_path:
+                    try:
+                        # Pipeline: filter frames -> pipe -> stream copy to final output
+                        filter_cmd = [
+                            "ffmpeg",
+                            "-nostdin",
+                            "-y",
+                            "-i",
+                            str(original_video),
+                            "-vf",
+                            vf,
+                            "-af",
+                            af,
+                            "-f",
+                            "matroska",  # Use MKV for better streaming compatibility
+                            str(pipe_path),
+                        ]
 
-                try:
-                    # Pipeline: filter frames -> pipe -> stream copy to final output
-                    filter_cmd = [
-                        "ffmpeg",
-                        "-nostdin",
-                        "-y",
-                        "-i",
-                        str(original_video),
-                        "-vf",
-                        vf,
-                        "-af",
-                        af,
-                        "-f",
-                        "matroska",  # Use MKV for better streaming compatibility
-                        str(pipe_path),
-                    ]
+                        copy_cmd = [
+                            "ffmpeg",
+                            "-nostdin",
+                            "-y",
+                            "-fflags",
+                            "nobuffer",
+                            "-i",
+                            str(pipe_path),
+                            "-c",
+                            "copy",  # Stream copy from pipe
+                            "-movflags",
+                            "+faststart",
+                            str(output_video),
+                        ]
 
-                    copy_cmd = [
-                        "ffmpeg",
-                        "-nostdin",
-                        "-y",
-                        "-fflags",
-                        "nobuffer",
-                        "-i",
-                        str(pipe_path),
-                        "-c",
-                        "copy",  # Stream copy from pipe
-                        "-movflags",
-                        "+faststart",
-                        str(output_video),
-                    ]
+                        logger.info("Using named pipe for frame removal streaming (MKV container)")
+                        logger.debug(f"Filter command with -nostdin: {' '.join(filter_cmd)}")
+                        logger.debug(f"Copy command with -nostdin: {' '.join(copy_cmd)}")
 
-                    logger.info("Using named pipe for frame removal streaming (MKV container)")
-                    logger.debug(f"Filter command with -nostdin: {' '.join(filter_cmd)}")
-                    logger.debug(f"Copy command with -nostdin: {' '.join(copy_cmd)}")
+                        # Start filter process in background
+                        filter_proc = subprocess.Popen(filter_cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
-                    # Start filter process in background
-                    filter_proc = subprocess.Popen(filter_cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+                        # Start copy process (blocks until complete)
+                        subprocess.run(copy_cmd, capture_output=True, text=True, check=True)
 
-                    # Start copy process (blocks until complete)
-                    subprocess.run(copy_cmd, capture_output=True, text=True, check=True)
+                        # Wait for filter to complete
+                        filter_proc.communicate()
 
-                    # Wait for filter to complete
-                    filter_proc.communicate()
+                        logger.debug("Streaming frame removal completed via named pipe")
 
-                    logger.debug("Streaming frame removal completed via named pipe")
-
-                finally:
-                    # Clean up pipe
-                    if pipe_path.exists():
-                        try:
-                            pipe_path.unlink()
-                            pipe_path.parent.rmdir()
-                        except OSError:
-                            pass
+                    finally:
+                        # Clean up pipe
+                        if pipe_path.exists():
+                            try:
+                                pipe_path.unlink()
+                                pipe_path.parent.rmdir()
+                            except OSError:
+                                pass
 
             else:
                 # Direct processing for larger removals or when pipes unavailable
@@ -767,9 +761,8 @@ class FrameCleaner:
         self,
         gray_frame: np.ndarray,
         endoscope_image_roi: Optional[dict | None],
-        endoscope_data_roi_nested: Optional[dict[str, dict[str, int | None] | None]],
+        endoscope_data_roi_nested: Optional[dict[str, dict[str, int | None]] | list | None],
         frame_id: int | None = None,
-        extended: bool = False,
         collect_for_batch: bool = False,
     ) -> tuple[bool, dict, str, float]:
         """
@@ -801,7 +794,6 @@ class FrameCleaner:
                 }
             )
 
-
         return is_sensitive, frame_metadata, ocr_text, ocr_conf
 
     def process_frames(
@@ -809,7 +801,6 @@ class FrameCleaner:
         frames: list[np.ndarray],
         endoscope_image_roi: dict | None = None,
         endoscope_data_roi_nested: dict | None = None,
-        extended: bool = False,
     ) -> list[tuple[bool, dict, str, float]]:
         """
         Batch-Verarbeitung aller Frames mit optionalem Batch-Enrichment.
@@ -823,12 +814,11 @@ class FrameCleaner:
                 endoscope_image_roi=endoscope_image_roi,
                 endoscope_data_roi_nested=endoscope_data_roi_nested,
                 frame_id=i,
-                extended=extended,
-                collect_for_batch=extended,
+                collect_for_batch=True,
             )
             results.append((is_sensitive, meta, text, conf))
         # Nach Batch: Metadaten-Anreicherung
-        if extended and self.frame_collection:
+        if self.frame_collection:
             batch_meta = self._extract_enriched_metadata_batch()
             if batch_meta:
                 logger.info(f"Merging batch-enriched metadata with accumulated results")
@@ -1053,7 +1043,7 @@ class FrameCleaner:
             pass
 
         # Calculate adaptive skip for sampling
-        skip = math.ceil(total_frames / 50)
+        skip = max(1, math.ceil(total_frames / 50))
         idx = 0
 
         while True:
@@ -1104,6 +1094,12 @@ class FrameCleaner:
                 "center": merged.get("center"),
             }
 
+            # Default center fallback
+            if not data.get("center") or data["center"] in (None, "", "Unknown"):
+                default_center = os.environ.get("DEFAULT_CENTER", "Endoscopy Center")
+                data["center"] = default_center
+                logger.debug(f"No center detected — using default: {default_center}")
+
             new_meta = SensitiveMeta.from_dict(data)
             if new_meta != self.sensitive_meta:
                 self.sensitive_meta = new_meta
@@ -1136,7 +1132,7 @@ class FrameCleaner:
         if getattr(self, "use_llm", False) and getattr(self, "ollama_extractor", None) is not None:
             if self.ollama_extractor is None:
                 logger.warning("Ollama extractor not initialized despite use_llm=True")
-                meta={}
+                meta = {}
             try:
                 meta_obj = self.ollama_extractor.extract_metadata(text)  # Pydantic-Objekt oder None
                 if meta_obj:
@@ -1208,7 +1204,6 @@ class FrameCleaner:
 
         return enriched_metadata
 
-
     def _reset_frame_collection(self):
         """Setzt die Frame-Sammlung für ein neues Video zurück."""
         self.frame_collection.clear()
@@ -1218,39 +1213,149 @@ class FrameCleaner:
     def _ocr_with_tesserocr(
         self,
         gray_frame: np.ndarray,
-        endoscope_data_roi_nested: Optional[dict[str, dict[str, int | None] | None]],
+        endoscope_data_roi_nested: Optional[dict[str, dict[str, int | None]] | list | None],
     ) -> tuple[str, float, dict, bool]:
         """
-        OCR mit TesserOCR und Metadatenextraktion.
+        OCR with TesserOCR and metadata extraction.
+        Handles both dict-based and list-based ROI structures gracefully.
+        Includes enhanced validation to filter gibberish output.
         """
         try:
-            logger.debug("Using TesserOCR OCR engine")
+            logger.debug("Using TesserOCR OCR engine with enhanced validation")
             frame_metadata: Dict[str, Any] = {}
-            if endoscope_data_roi_nested is None:
-                endoscope_data_roi_nested = {}
-                ocr_text, ocr_conf, _ = self.frame_ocr.extract_text_from_frame(gray_frame, roi=endoscope_data_roi_nested, high_quality=True)
+            ocr_text = ""
+            valid_texts = []  # Store only validated text
+
+            # --- Normalize input ROI structure ---
+            rois: list[dict[str, int | None]] = []
+
+            if not endoscope_data_roi_nested:
                 has_roi = False
-            else:
-                logger.debug(f"Using endoscope_data_roi_nested: {endoscope_data_roi_nested}")
-                for key, roi in endoscope_data_roi_nested.items():
-                    logger.debug(f"ROI for {key}: {roi}")
-                    output, ocr_conf, _ = self.frame_ocr.extract_text_from_frame(gray_frame, roi=roi, high_quality=True)
-                    # No RegEx filtering here; keep all text for metadata extraction
-                    frame_metadata[key] = output
-                    ocr_text = output if not ocr_text else ocr_text + "\n" + output
+            elif isinstance(endoscope_data_roi_nested, dict):
+                # Original expected format
+                rois = list(endoscope_data_roi_nested.values())
                 has_roi = True
+            elif isinstance(endoscope_data_roi_nested, list):
+                # Flatten nested lists of dicts
+                for item in endoscope_data_roi_nested:
+                    if isinstance(item, dict):
+                        rois.append(item)
+                    elif isinstance(item, list):
+                        for sub in item:
+                            if isinstance(sub, dict):
+                                rois.append(sub)
+                has_roi = len(rois) > 0
+            else:
+                logger.warning(f"Unexpected ROI type: {type(endoscope_data_roi_nested)}")
+                has_roi = False
 
-            logger.debug(f"TesserOCR extracted text length: {len(ocr_text or '')}, conf: {ocr_conf:.3f}")
+            # --- Run OCR ---
             if not has_roi:
-                logger.debug("No ROI provided, using regex based metadata extraction")
-                frame_metadata = self.frame_metadata_extractor.extract_metadata_from_frame_text(ocr_text) if ocr_text else {}
-            is_sensitive = self.frame_metadata_extractor.is_sensitive_content(frame_metadata)
+                ocr_text, ocr_conf, _ = self.frame_ocr.extract_text_from_frame(gray_frame, roi={}, high_quality=True)
 
+                # Validate full-frame OCR
+                if self._is_valid_ocr_text(ocr_text):
+                    valid_texts.append(ocr_text)
+                else:
+                    logger.debug(f"Full-frame OCR produced invalid text, filtering: {ocr_text[:100]}")
+                    ocr_text = ""
+            else:
+                ocr_conf = 0.0
+                for i, roi in enumerate(rois):
+                    output, conf, _ = self.frame_ocr.extract_text_from_frame(gray_frame, roi=roi, high_quality=True)
+
+                    # Validate each ROI's OCR output
+                    if self._is_valid_ocr_text(output):
+                        valid_texts.append(output)
+                        frame_metadata[f"roi_{i}"] = output
+                        ocr_conf = max(ocr_conf, conf)
+                    else:
+                        logger.debug(f"ROI {i} produced invalid text (filtered): {output[:50]}")
+                        frame_metadata[f"roi_{i}"] = ""
+
+                # Combine only valid texts
+                ocr_text = "\n".join(valid_texts)
+
+            logger.debug(f"TesserOCR extracted {len(valid_texts)} valid text regions, total length: {len(ocr_text)}, conf: {ocr_conf:.3f}")
+
+            # --- Metadata Extraction ---
+            # Always try to extract metadata from the combined OCR text
+            if ocr_text:
+                logger.debug("Extracting metadata from combined OCR text")
+                extracted_meta = self.frame_metadata_extractor.extract_metadata_from_frame_text(ocr_text)
+                # Merge extracted metadata with ROI metadata
+                frame_metadata.update(extracted_meta)
+
+            is_sensitive = self.frame_metadata_extractor.is_sensitive_content(frame_metadata)
             return ocr_text, ocr_conf, frame_metadata, is_sensitive
+
         except Exception as e:
             logger.exception(f"TesserOCR OCR failed: {e}")
             return "", 0.0, {}, False
 
+    def _is_valid_ocr_text(self, text: str, min_alpha_ratio: float = 0.20, min_length: int = 3) -> bool:
+        """
+        Validate OCR text to filter out gibberish.
+
+        Args:
+            text: OCR extracted text
+            min_alpha_ratio: Minimum ratio of alphabetic characters (default 0.20, relaxed from 0.35)
+            min_length: Minimum text length (default 3)
+
+        Returns:
+            True if text appears valid, False if likely gibberish
+        """
+        if not text or len(text.strip()) < min_length:
+            return False
+
+        # Special case: Allow date/time patterns (have few letters but are valid)
+        # Examples: "09:53:32", "2024-01-15", "15702/2024", "E 15702/2024809:53:32"
+        import re
+
+        # Time patterns: HH:MM:SS or HH:MM
+        time_pattern = r"\d{1,2}:\d{2}(?::\d{2})?"
+        # Date patterns: YYYY-MM-DD, DD.MM.YYYY, YYYY/MM/DD
+        date_pattern = r"\d{4}[-./]\d{1,2}[-./]\d{1,2}|\d{1,2}[-./]\d{1,2}[-./]\d{4}"
+        # Case number patterns: E 12345/2024 or similar
+        case_pattern = r"[A-Z]\s*\d{4,}/\d{4}"
+        # Device ID patterns: long numbers with optional separators
+        device_pattern = r"\d{8,}"
+
+        if re.search(time_pattern, text) or re.search(date_pattern, text) or re.search(case_pattern, text) or re.search(device_pattern, text):
+            # Contains structured data patterns - likely valid
+            return True
+
+        # Calculate alphabetic character ratio
+        alpha_count = sum(c.isalpha() for c in text)
+        alpha_ratio = alpha_count / len(text)
+
+        # Relaxed from 0.35 to 0.20 to allow more numeric/mixed content
+        if alpha_ratio < min_alpha_ratio:
+            return False
+
+        # Check for excessive special characters
+        expected_chars = set("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyzÄÖÜäöüß0123456789 .,:;/-()[]")
+        nonstandard = sum(1 for c in text if c not in expected_chars)
+
+        # Relaxed from 0.3 to 0.4 to allow more special characters
+        if nonstandard > 0.4 * len(text):
+            return False
+
+        # Check for reasonable word structure
+        words = [w for w in text.split() if len(w) > 1]
+        if not words:
+            return False
+
+        # Most words should have vowels (German/English)
+        vowels = set("aeiouäöüAEIOUÄÖÜ")
+        words_with_vowels = sum(1 for word in words if any(c in vowels for c in word))
+
+        # Relaxed from 0.25 to 0.15 to allow more abbreviations/codes
+        if len(words) > 2 and words_with_vowels < 0.15 * len(words):
+            return False
+
+        return True
+
     def remove_frames_from_video(
         self,
         original_video: Path,
@@ -1355,11 +1460,10 @@ class FrameCleaner:
         stub = {
             "image_width": 1920,
             "image_height": 1080,
-            "endoscope_image_x": 550,
-            "endoscope_image_y": 0,
-            "endoscope_image_width": 1350,
-            "endoscope_image_height": 1080,
-            "description": f"Mask configuration for {device_name}",
+            "x": 550,
+            "y": 0,
+            "width": 1350,
+            "height": 1080,
         }
 
         try:
@@ -1393,10 +1497,20 @@ class FrameCleaner:
             True if masking succeeded, False otherwise
         """
         try:
-            endoscope_x = mask_config.get("endoscope_image_x")
-            endoscope_y = mask_config.get("endoscope_image_y")
-            endoscope_w = mask_config.get("endoscope_image_width")
-            endoscope_h = mask_config.get("endoscope_image_height")
+            if mask_config == {}:
+                load_mask_config = self._load_mask(device_name="default")
+                normalized = normalize_roi_keys(load_mask_config)
+                mask_config = normalized if normalized is not None else {}
+                logger.info("Using default mask configuration")
+
+            normalized = normalize_roi_keys(mask_config)
+            if normalized is not None:
+                mask_config = normalized
+
+            endoscope_x = mask_config.get("x")
+            endoscope_y = mask_config.get("y")
+            endoscope_w = mask_config.get("width")
+            endoscope_h = mask_config.get("height")
 
             # Check if we can use simple crop (left strip masking)
             if endoscope_y == 0 and endoscope_h == mask_config.get("image_height", 1080):
@@ -1503,11 +1617,12 @@ class FrameCleaner:
         if not isinstance(roi, dict):
             return False
 
-        required_keys = ["x", "y", "width", "height"]
-        if not all(key in roi for key in required_keys):
-            logger.warning(f"ROI missing required keys. Expected: {required_keys}, got: {list(roi.keys())}")
+        normalized = normalize_roi_keys(roi)
+        if not normalized:
             return False
 
+        roi = normalized
+
         # Check for reasonable values (non-negative, not too large)
         try:
             x, y, width, height = roi["x"], roi["y"], roi["width"], roi["height"]
@@ -1530,7 +1645,6 @@ class FrameCleaner:
             logger.warning(f"ROI contains invalid values: {roi}, error: {e}")
             return False
 
-
     # def _ocr_with_minicpm(self, gray_frame: np.ndarray) -> tuple[str, float, dict, bool]:
     #     """
     #     OCR mit MiniCPM LLM-basiertem Modell. Fallback auf TesserOCR bei Fehler.
