@@ -1,7 +1,5 @@
 from pathlib import Path
 import fitz
-import cv2
-import uuid
 from .custom_logger import get_logger
 
 logger = get_logger(__name__)
@@ -13,7 +11,7 @@ def get_image_paths(image_or_pdf_path: Path, temp_dir: Path):
     if not temp_dir.exists() or not temp_dir.is_dir():
         raise ValueError(f"Temporary directory {temp_dir} does not exist or is not a directory.")
 
-    if image_or_pdf_path.suffix.lower() == '.pdf':
+    if image_or_pdf_path.suffix.lower() == ".pdf":
         try:
             doc = fitz.open(str(image_or_pdf_path))  # fitz expects a string
             for page_num in range(len(doc)):
@@ -29,4 +27,4 @@ def get_image_paths(image_or_pdf_path: Path, temp_dir: Path):
             raise FileNotFoundError(f"The file {image_or_pdf_path} does not exist.")
         image_paths.append(image_or_pdf_path)
 
-    return image_paths
\ No newline at end of file
+    return image_paths
