@@ -6,25 +6,34 @@ from pathlib import Path
 
 import cv2
 import pymupdf
+import pytesseract
 import torch
+from PIL import Image
 
 from .blur import blur_function
-from .box_operations import (close_to_box, combine_boxes, filter_empty_boxes,
-                             find_or_create_close_box, get_dominant_color)
-from .craft_text_detection import craft_text_detection
+from .box_operations import close_to_box, combine_boxes, filter_empty_boxes, find_or_create_close_box, get_dominant_color
+
+# Import CRAFT text detection if available (requires hezar)
+try:
+    from .craft_text_detection import craft_text_detection
+
+    CRAFT_AVAILABLE = True
+except ImportError:
+    CRAFT_AVAILABLE = False
+
+    def craft_text_detection(*args, **kwargs):
+        raise ImportError("CRAFT text detection requires 'hezar' package. Install with: pip install lx-anonymizer[llm]")
+
+
 from .custom_logger import get_logger
 from .device_reader import read_background_color, read_name_boxes
 from .directory_setup import create_blur_directory, create_temp_directory
 from .east_text_detection import east_text_detection
 from .flair_NER import flair_NER_German
 from .fuzzy_matching import correct_box_for_new_text, fuzzy_match_snippet
-from .lx_anonymizer.lx_anonymizer.llm_phi4 import (
-    analyze_full_image_with_context, analyze_text_with_phi4)
-from .names_generator import (gender_and_handle_device_names,
-                              gender_and_handle_full_names,
-                              gender_and_handle_separate_names)
-from .ocr import (tesseract_full_image_ocr, tesseract_on_boxes,
-                      trocr_on_boxes)
+from .names_generator import gender_and_handle_device_names, gender_and_handle_full_names, gender_and_handle_separate_names
+from .ocr import tesseract_full_image_ocr, tesseract_on_boxes, trocr_on_boxes
+from .ollama_llm_meta_extraction_optimized import OllamaOptimizedExtractor
 from .spacy_NER import spacy_NER_German
 from .tesseract_text_detection import tesseract_text_detection
 
@@ -32,10 +41,12 @@ from .tesseract_text_detection import tesseract_text_detection
 logger = get_logger(__name__)
 
 
-def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detection.pb', device="default", min_confidence=0.5, width=320, height=320, skip_blur=False, skip_reassembly=False):
+def process_images_with_OCR_and_NER(
+    file_path, east_path="frozen_east_text_detection.pb", device="default", min_confidence=0.5, width=320, height=320, skip_blur=False, skip_reassembly=False
+):
     """
     Process images with OCR and NER.
-    
+
     Parameters:
     - file_path: str
         The path to the image or PDF file to process.
@@ -62,25 +73,25 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
     gender_pars = []
 
     try:
-        file_extension = file_path.suffix.lower().lstrip('.')  # lstrip removes the leading '.'        
+        file_extension = file_path.suffix.lower().lstrip(".")  # lstrip removes the leading '.'
         mime_types = {
-            'jpg': 'image/jpeg',
-            'jpeg': 'image/jpeg',
-            'png': 'image/png',
-            'gif': 'image/gif',
-            'bmp': 'image/bmp',
-            'tiff': 'image/tiff',
-            'pdf': 'application/pdf',
+            "jpg": "image/jpeg",
+            "jpeg": "image/jpeg",
+            "png": "image/png",
+            "gif": "image/gif",
+            "bmp": "image/bmp",
+            "tiff": "image/tiff",
+            "pdf": "application/pdf",
         }
-        file_type = mime_types.get(file_extension, 'application/octet-stream').split('/')[-1]
+        file_type = mime_types.get(file_extension, "application/octet-stream").split("/")[-1]
 
-        if file_type not in ['jpg', 'jpeg', 'png', 'tiff', 'pdf']:
-            raise ValueError('Invalid file type.')
+        if file_type not in ["jpg", "jpeg", "png", "tiff", "pdf"]:
+            raise ValueError("Invalid file type.")
 
         image_paths = []
-        extracted_text = ''
+        extracted_text = ""
 
-        if file_type == 'pdf':
+        if file_type == "pdf":
             # Open PDF using pymupdf
             doc = pymupdf.open(file_path)
             for page_num in range(len(doc)):
@@ -99,13 +110,6 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
             error_message = "No images to process."
             logger.error(error_message)
             raise RuntimeError(error_message)
-            
-        # If we have extracted text and we're skipping blur, analyze with LLM first
-        if extracted_text and skip_blur:
-            logger.info("Analyzing extracted text with LLM")
-            text_csv_path = csv_dir / f"text_analysis_{uuid.uuid4()}.csv"
-            text_results, _ = analyze_text_with_phi4(extracted_text, text_csv_path, file_path)
-            logger.info(f"LLM text analysis results: {text_results}")
 
         blurred_image_path = image_paths[0]
         for img_path in image_paths:
@@ -122,18 +126,46 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
             # Handle LLM analysis of the image
             if skip_blur:
                 logger.info("Skipping blur, running LLM analysis on image")
-                llm_csv_path = csv_dir / f"image_analysis_{uuid.uuid4()}.csv"
-                image_results, _ = analyze_full_image_with_context(img_path, llm_csv_path, csv_dir)
-                logger.info(f"LLM image analysis results: {len(image_results) if image_results else 0} entities")
-            else:
-                # Regular blur processing 
+                # Create OllamaOptimizedExtractor instance
+                extractor = OllamaOptimizedExtractor()
+
+                # Extract text from image for LLM analysis
+                try:
+                    image = Image.open(img_path).convert("RGB")
+                    ocr_text = pytesseract.image_to_string(image)
+                except Exception as e:
+                    logger.warning(f"Failed to extract OCR text: {e}")
+                    ocr_text = ""
+
+                # Use LLM to analyze the extracted text
+                if ocr_text:
+                    llm_metadata = extractor.extract_metadata(ocr_text)
+                    if llm_metadata:
+                        llm_results = {
+                            "patient_name": llm_metadata.patient_name,
+                            "patient_age": llm_metadata.patient_age,
+                            "examination_date": llm_metadata.examination_date,
+                            "gender": llm_metadata.gender,
+                            "casenumber": llm_metadata.casenumber,
+                            "examiner_first_name": llm_metadata.examiner_first_name,
+                            "examiner_last_name": llm_metadata.examiner_last_name,
+                        }
+                    else:
+                        llm_results = {}
+                else:
+                    llm_results = {}
+
+            logger.info(f"LLM image analysis results: {len(llm_results) if llm_results else 0} entities")
+
+            # Regular blur processing (only if not skipping blur)
+            if not skip_blur:
                 if first_name_box and last_name_box:
                     blurred_image_path = blur_function(blurred_image_path, first_name_box, background_color)
                     blurred_image_path = blur_function(blurred_image_path, last_name_box, background_color)
 
             east_boxes, east_confidences_json = east_text_detection(img_path, east_path, min_confidence, width, height)
             tesseract_boxes, tesseract_confidences_json = tesseract_text_detection(img_path, min_confidence, width, height)
-            craft_boxes, craft_confidences_json = craft_text_detection(img_path, min_confidence, width, height)  
+            craft_boxes, craft_confidences_json = craft_text_detection(img_path, min_confidence, width, height)
             combined_boxes = east_boxes + tesseract_boxes + craft_boxes
 
             logger.info("Running OCR on boxes")
@@ -145,24 +177,20 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
             east_confidences = json.loads(east_confidences_json)
             tesseract_confidences = json.loads(tesseract_confidences_json)
             craft_confidences = json.loads(craft_confidences_json)
-            
-            all_text_detection_confidences = (
-                east_confidences +
-                tesseract_confidences +
-                craft_confidences
-            )
+
+            all_text_detection_confidences = east_confidences + tesseract_confidences + craft_confidences
             all_ocr_results = filter_empty_boxes(all_ocr_results)
 
             # If you need it as JSON later:
             all_text_detection_confidences_json = json.dumps(all_text_detection_confidences)
-            
+
             for (phrase, phrase_box), ocr_confidence in zip(all_ocr_results, all_ocr_confidences):
                 # Skip blur operations if requested
                 if skip_blur:
                     # Just collect OCR results without blurring
                     combined_results.append((phrase, phrase_box, ocr_confidence, []))
                     continue
-                
+
                 # Normal processing path with fuzzy correction and blurring
                 blurred_image_path, modified_images_map, combined_results, updated_genders = do_ocr_with_fuzzy_correction(
                     all_ocr_results=all_ocr_results,
@@ -175,18 +203,14 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
                     combined_boxes=combined_boxes,
                     first_name_box=first_name_box,
                     last_name_box=last_name_box,
-                    full_text_candidates=phrase
+                    full_text_candidates=phrase,
                 )
                 gender_pars.extend(updated_genders)
 
         # Prepare CSV writing
         csv_path = csv_dir / f"name_anonymization_data_i{Path(file_path).stem}{uuid.uuid4()}.csv"
-        with open(csv_path, mode='w', newline='', encoding='utf-8') as csv_file:
-            fieldnames = [
-                'filename', 'startX', 'startY', 'endX', 'endY', 
-                'text', 'phrase_box', 'ocr_confidence', 
-                'entity_text', 'entity_tag'
-            ]            
+        with open(csv_path, mode="w", newline="", encoding="utf-8") as csv_file:
+            fieldnames = ["filename", "startX", "startY", "endX", "endY", "text", "phrase_box", "ocr_confidence", "entity_text", "entity_tag"]
             writer = csv.DictWriter(csv_file, fieldnames=fieldnames)
 
             writer.writeheader()
@@ -195,29 +219,31 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
                 phrase, phrase_box, ocr_confidence, entities = combined_result
                 startX, startY, endX, endY = phrase_box
                 for entity_text, entity_tag in entities:
-                    writer.writerow({
-                        'filename': file_path,
-                        'startX': startX,
-                        'startY': startY,
-                        'endX': endX,
-                        'endY': endY,
-                        'text': phrase,
-                        'phrase_box': phrase_box,
-                        'ocr_confidence': ocr_confidence,
-                        'entity_text': entity_text,
-                        'entity_tag': entity_tag
-                    })
+                    writer.writerow(
+                        {
+                            "filename": file_path,
+                            "startX": startX,
+                            "startY": startY,
+                            "endX": endX,
+                            "endY": endY,
+                            "text": phrase,
+                            "phrase_box": phrase_box,
+                            "ocr_confidence": ocr_confidence,
+                            "entity_text": entity_text,
+                            "entity_tag": entity_tag,
+                        }
+                    )
 
         logger.info(f"NER results saved to {csv_path}")
 
         result = {
-            'filename': file_path,
-            'file_type': file_type,
-            'extracted_text': extracted_text,
-            'names_detected': names_detected,
-            'combined_results': combined_results,
-            'modified_images_map': modified_images_map,
-            'gender_pars': gender_pars
+            "filename": file_path,
+            "file_type": file_type,
+            "extracted_text": extracted_text,
+            "names_detected": names_detected,
+            "combined_results": combined_results,
+            "modified_images_map": modified_images_map,
+            "gender_pars": gender_pars,
         }
 
         # If not skipping blur and we have a blurred image path
@@ -228,13 +254,11 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
             final_image = cv2.imread(str(blurred_image_path))
             cv2.imwrite(str(output_path), final_image)
             logger.info(f"Final blurred image saved to: {output_path}")
-        
-        # Always run LLM analysis and add results 
-        llm_results, llm_csv_path = analyze_full_image_with_context(file_path, csv_path, csv_dir)
-        result['llm_results'] = llm_results
-        result['llm_csv_path'] = llm_csv_path
 
-        logger.info(f"Processing completed: {len(combined_results)} results, csv: {csv_path}, llm results: {llm_csv_path}")
+        # Always run LLM analysis and add results
+        result["llm_results"] = llm_results
+
+        logger.info(f"Processing completed: {len(combined_results)} results, csv: {csv_path}")
         return modified_images_map, result
     except Exception as e:
         error_message = f"Error in process_images_with_OCR_and_NER: {e}, File Path: {file_path}"
@@ -242,12 +266,12 @@ def process_images_with_OCR_and_NER(file_path, east_path='frozen_east_text_detec
         raise RuntimeError(error_message)
 
 
-
 def process_text(extracted_text):
-    cleaned_text = re.sub(r'\n{2,}', '\n', extracted_text)
+    cleaned_text = re.sub(r"\n{2,}", "\n", extracted_text)
     cleaned_text = cleaned_text.replace("\n", " ")
     return cleaned_text
 
+
 from typing import Dict, List, Optional, Tuple  # Added Optional
 
 
@@ -261,13 +285,13 @@ def process_ocr_results(
     device: str,
     modified_images_map: Dict[Tuple[str, str], str],
     combined_boxes: List[Tuple[int, int, int, int]],
-    first_name_box: Optional[Tuple[int, int, int, int]] = None, # Changed here
-    last_name_box: Optional[Tuple[int, int, int, int]] = None # Changed here
+    first_name_box: Optional[Tuple[int, int, int, int]] = None,  # Changed here
+    last_name_box: Optional[Tuple[int, int, int, int]] = None,  # Changed here
 ) -> Tuple[str, Dict[Tuple[str, str], str], List[Tuple[str, Tuple[int, int, int, int], float, List[Tuple[str, str]]]], List[str]]:
     processed_text = process_text(phrase)
     entities = split_and_check(processed_text)
     logger.info(f"Entities detected: {entities}")
-    
+
     box_to_image_map = {}
     gender_pars = []  # Changed from {} to []
     new_image_path = image_path  # Keep track of the current image path being manipulated
@@ -292,6 +316,7 @@ def process_ocr_results(
     combined_results.append((phrase, phrase_box, ocr_confidence, entities))
     return new_image_path, modified_images_map, combined_results, gender_pars  # Always return the last modified path
 
+
 def do_ocr_with_fuzzy_correction(
     all_ocr_results,
     all_ocr_confidences,
@@ -303,21 +328,20 @@ def do_ocr_with_fuzzy_correction(
     combined_boxes,
     first_name_box=None,
     last_name_box=None,
-    full_text_candidates=None
+    full_text_candidates=None,
 ):
     """
     Demonstrates how to integrate fuzzy matching and box correction
     into your existing loop before calling 'process_ocr_results'.
     """
-    # If you don't have a big list of words, you can pass in your entire recognized text 
+    # If you don't have a big list of words, you can pass in your entire recognized text
     # as e.g. `full_text_candidates = full_text.split()`.
     if full_text_candidates is None:
         full_text_candidates = []
 
     updated_genders = []
 
-    for ((snippet_text, snippet_box), snippet_conf) in zip(all_ocr_results, all_ocr_confidences):
-
+    for (snippet_text, snippet_box), snippet_conf in zip(all_ocr_results, all_ocr_confidences):
         # 1) Fuzzy match the snippet_text against a global list or full-image words
         best_match, ratio = fuzzy_match_snippet(snippet_text, full_text_candidates, threshold=0.7)
 
@@ -331,13 +355,7 @@ def do_ocr_with_fuzzy_correction(
             corrected_text = best_match
 
             # 3) Adjust bounding box if the new text is longer
-            corrected_box = correct_box_for_new_text(
-                blurred_image_path,
-                snippet_box,
-                old_text=snippet_text,
-                new_text=corrected_text,
-                extension_margin=15
-            )
+            corrected_box = correct_box_for_new_text(blurred_image_path, snippet_box, old_text=snippet_text, new_text=corrected_text, extension_margin=15)
 
         # 4) Now feed the (corrected) text + box to your NER and anonymization logic
         blurred_image_path, modified_images_map, combined_results, genders = process_ocr_results(
@@ -351,7 +369,7 @@ def do_ocr_with_fuzzy_correction(
             modified_images_map,
             combined_boxes,
             first_name_box,
-            last_name_box
+            last_name_box,
         )
         updated_genders.extend(genders)
 
@@ -360,48 +378,47 @@ def do_ocr_with_fuzzy_correction(
 
 def modify_image_for_name(image_path, phrase_box, combined_boxes):
     image = cv2.imread(str(image_path))
-    image_height, image_width, _ = image.shape  
+    image_height, image_width, _ = image.shape
     last_name_box = find_or_create_close_box(phrase_box, combined_boxes, image_width)
-    
+
     temp_dir, base_dir, csv_dir = create_temp_directory()
     temp_image_path = Path(temp_dir) / f"{uuid.uuid4()}.jpg"
     cv2.imwrite(str(temp_image_path), image)
-    
+
     return blur_function(temp_image_path, phrase_box), last_name_box
 
+
 def split_and_check(phrase):
     # Initialize an empty list to store entities
     all_entities = []
-    
+
     # Get entities from spaCy
     spacy_entities = spacy_NER_German(phrase)
     if spacy_entities:
-        all_entities.extend([(entity[0], 'PER') for entity in spacy_entities if entity[3] == 'PER'])
-    
+        all_entities.extend([(entity[0], "PER") for entity in spacy_entities if entity[3] == "PER"])
+
     # Get entities from Flair
     flair_entities = flair_NER_German(phrase)
     if flair_entities:
-        all_entities.extend([(entity.text, 'PER') for entity in flair_entities if entity.tag == 'PER'])
-    
+        all_entities.extend([(entity.text, "PER") for entity in flair_entities if entity.tag == "PER"])
+
     if all_entities:
         return all_entities
-        
+
     # If no entities found, try with parts of the phrase
-    parts = [phrase[:3], phrase[-3:], phrase[:4] + phrase[-4:], 
-            phrase[:5] + phrase[-5:], phrase[:6] + phrase[-6:]]
-    
+    parts = [phrase[:3], phrase[-3:], phrase[:4] + phrase[-4:], phrase[:5] + phrase[-5:], phrase[:6] + phrase[-6:]]
+
     for part in parts:
         spacy_entities = spacy_NER_German(part)
         if spacy_entities:
-            entities = [(entity[0], 'PER') for entity in spacy_entities if entity[3] == 'PER']
+            entities = [(entity[0], "PER") for entity in spacy_entities if entity[3] == "PER"]
             if entities:
                 return entities
-                
+
         flair_entities = flair_NER_German(part)
         if flair_entities:
-            entities = [(entity.text, 'PER') for entity in flair_entities if entity.tag == 'PER']
+            entities = [(entity.text, "PER") for entity in flair_entities if entity.tag == "PER"]
             if entities:
                 return entities
-    
-    return []
 
+    return []
